@@ -10,6 +10,7 @@
 #'   \item{\code{call(inputs,mask)}}{Call the layer on an input tensor.}
 #'   \item{\code{compute_output_shape(input_shape)}}{Compute the output shape
 #'   for the layer.}
+#'   \item{\code{add_loss(losses, inputs)}}{Add losses to the layer.}
 #'   \item{\code{add_weight(name,shape,dtype,initializer,regularizer,trainable,constraint)}}{Adds
 #'   a weight variable to the layer.} }
 #'
@@ -62,6 +63,10 @@ KerasLayer <- R6Class("KerasLayer",
     # back reference to python layer that wraps us
     .set_wrapper = function(wrapper) {
       private$wrapper <- wrapper
+    },
+    
+    python_layer = function() {
+      private$wrapper
     }
   ),
   
