@@ -25,6 +25,11 @@ skip_if_cntk <- function() {
     skip("Test not run for CNTK backend")
 }
 
+skip_if_theano <- function() {
+  if (is_backend("theano"))
+    skip("Test not run for theano backend")
+}
+
 skip_if_tensorflow_implementation <- function() {
   if (keras:::is_tensorflow_implementation())
     skip("Test not run for TensorFlow implementation")
